@@ -1,38 +1,50 @@
-from typing import Dict, Any, Optional
+from typing import Dict, Any, Tuple, List, Union
 
 from aiohttp import web as aio_web
 
-from bolinette.blnt.database import DatabaseManager
-from bolinette.docs import Documentation
-from bolinette.utils import paths, files
-
-from bolinette import blnt, core, web, mapping
+from bolinette import blnt, core, web, mapping, BolinetteExtension, Extensions
 from bolinette.exceptions import InternalError
+from bolinette.blnt.database import DatabaseManager
+from bolinette.utils import paths, files
+from bolinette.docs import Documentation
 
 
 class BolinetteContext:
-    def __init__(self, origin: str, app: Optional[aio_web.Application], *, profile=None, overrides=None):
+    def __init__(self, origin: str, *, extensions: List[BolinetteExtension] = None,
+                 profile: str = None, overrides: Dict[str, Any] = None):
         self._ctx = {}
+        self._extensions = []
+        self._tables: Dict[str, Any] = {}
+        self._models: Dict[str, 'core.Model'] = {}
+        self._repos: Dict[str, 'core.Repository'] = {}
+        self._services: Dict[str, 'core.Service'] = {}
+        self._controllers: Dict[str, 'web.Controller'] = {}
+
+        for ext in extensions or []:
+            self.use_extension(ext)
+
+        self.app = None
         self.cwd = paths.cwd()
         self.origin = origin
         self.env = blnt.Environment(self, profile=profile, overrides=overrides)
         self.manifest = files.read_manifest(
             self.root_path(), params={'version': self.env.get('version', '0.0.0')}) or {}
         self.logger = blnt.Logger(self)
-        if app is not None:
-            self.app = app
-            self.docs = Documentation(self)
-            self.db = DatabaseManager(self)
-            self.jwt = blnt.JWT(self)
-            self.resources = web.BolinetteResources(self)
-            self.sockets = web.BolinetteSockets(self)
-            self.mapper = mapping.Mapper(self)
-            self.validator = blnt.Validator(self)
-            self._tables: Dict[str, Any] = {}
-            self._models: Dict[str, 'core.Model'] = {}
-            self._repos: Dict[str, 'core.Repository'] = {}
-            self._services: Dict[str, 'core.Service'] = {}
-            self._controllers: Dict[str, 'web.Controller'] = {}
+        self.db = DatabaseManager(self)
+        self.mapper = mapping.Mapper(self)
+        self.validator = blnt.Validator(self)
+        self.jwt = blnt.JWT(self)
+        self.resources = web.BolinetteResources(self)
+        self.docs = Documentation(self)
+        self.sockets = web.BolinetteSockets(self)
+
+    def init_web(self, app: aio_web.Application):
+        self.app = app
+        self.resources.init_web(app)
+
+    def init_sockets(self, app: aio_web.Application):
+        self.app = app
+        self.sockets.init_socket_handler()
 
     def __getitem__(self, key):
         return self._ctx[key]
@@ -43,6 +55,24 @@ class BolinetteContext:
     def model(self, name) -> Any:
         return self._models[name]
 
+    def clear_extensions(self):
+        self._extensions = []
+
+    def use_extension(self, ext: BolinetteExtension):
+        if ext not in self._extensions:
+            for sub_ext in ext.dependencies:
+                self.use_extension(sub_ext)
+            self._extensions.append(ext)
+
+    def has_extension(self, ext: Union[Tuple[BolinetteExtension, ...], BolinetteExtension]):
+        if Extensions.ALL in self._extensions:
+            return True
+        if isinstance(ext, BolinetteExtension):
+            return ext in self._extensions
+        if isinstance(ext, tuple):
+            return len(ext) > 0 and any(self.has_extension(b) for b in ext)
+        raise ValueError('BolinetteContext.has_extensions only accepts BolinetteExtensions instances')
+
     def add_model(self, name, model: 'core.Model'):
         self._models[name] = model
 
